==> haskell-linear-1.22-79-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-linear.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 linear
version:              1.22
visibility:           public
id:                   linear-1.22-LXhCWfCwoOCLM6ORzrDiMg
key:                  linear-1.22-LXhCWfCwoOCLM6ORzrDiMg
license:              BSD-3-Clause
copyright:            Copyright (C) 2012-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/linear/
synopsis:             Linear Algebra
description:
    Types and combinators for linear algebra on free vector spaces

category:             Math, Algebra
abi:                  27d3f961ed02c7f041f91ae56934be04
exposed:              True
exposed-modules:
    Linear Linear.Affine Linear.Algebra Linear.Binary Linear.Conjugate
    Linear.Covector Linear.Epsilon Linear.Instances Linear.Matrix
    Linear.Metric Linear.Plucker Linear.Plucker.Coincides
    Linear.Projection Linear.Quaternion Linear.Trace Linear.V Linear.V0
    Linear.V1 Linear.V2 Linear.V3 Linear.V4 Linear.Vector

import-dirs:          /usr/lib/ghc-9.2.8/site-local/linear-1.22
library-dirs:         /usr/lib/ghc-9.2.8/site-local/linear-1.22
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-linear
hs-libraries:         HSlinear-1.22-LXhCWfCwoOCLM6ORzrDiMg
depends:
    adjunctions-4.4.2-ApoyVdBFoqF3BLalKvSmjf base-4.16.4.0
    base-orphans-0.8.8.2-GP2XGIWM9HZ1LQb4KpruLc binary-0.8.9.0
    bytes-0.17.3-bna73qV7Pb67whkO4XyO
    cereal-0.5.8.3-9zcITCTkqXtHoa6jbeSF22 containers-0.6.5.1
    deepseq-1.4.6.1 distributive-0.6.2.1-KkR7zsPK3feLSI7KIWSpvI
    ghc-prim-0.8.0 hashable-1.4.3.0-3dqA7o3S1KBIuEdO2YDkYf
    indexed-traversable-0.1.3-KIkqpQDZFwfC7v1aqBbIIv
    lens-5.2.3-DsU5WJ3RaWRHiptdGSZV2k
    random-1.2.1.2-I9vy4QvkbAYGYkQawOWCQJ
    reflection-2.1.7-1QYIVmmSwPu42Crf4M7Liq
    semigroupoids-5.3.7-4jaPvonLAsPBpig4bIcEIE
    tagged-0.8.8-404YCiJ2agdDxJGZ4AybXg template-haskell-2.18.0.0
    transformers-0.5.6.2
    transformers-compat-0.7.2-9ApmiRwA3hS7UuQpOomcS
    unordered-containers-0.2.20-2sfG1n18ekp4kj5cDOH71Y
    vector-0.13.1.0-BOAscM7GxpQxkvUjpqER4
    void-0.7.3-KUUN4OwBuM95y1GIrgJb5t

haddock-interfaces:   /usr/share/doc/haskell-linear/html/linear.haddock
haddock-html:         /usr/share/doc/haskell-linear/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-linear-1.22-80-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-linear.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 linear
version:              1.22
visibility:           public
id:                   linear-1.22-Fk4soyVIqDh79Givu0NH9z
key:                  linear-1.22-Fk4soyVIqDh79Givu0NH9z
license:              BSD-3-Clause
copyright:            Copyright (C) 2012-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/linear/
synopsis:             Linear Algebra
description:
    Types and combinators for linear algebra on free vector spaces

category:             Math, Algebra
abi:                  df0bb3713106dfcd5a1e4f1ece5cfc0c
exposed:              True
exposed-modules:
    Linear Linear.Affine Linear.Algebra Linear.Binary Linear.Conjugate
    Linear.Covector Linear.Epsilon Linear.Instances Linear.Matrix
    Linear.Metric Linear.Plucker Linear.Plucker.Coincides
    Linear.Projection Linear.Quaternion Linear.Trace Linear.V Linear.V0
    Linear.V1 Linear.V2 Linear.V3 Linear.V4 Linear.Vector

import-dirs:          /usr/lib/ghc-9.2.8/site-local/linear-1.22
library-dirs:         /usr/lib/ghc-9.2.8/site-local/linear-1.22
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-linear
hs-libraries:         HSlinear-1.22-Fk4soyVIqDh79Givu0NH9z
depends:
    adjunctions-4.4.2-BnoKoxPLrBrDkgInv6Pu8t base-4.16.4.0
    base-orphans-0.8.8.2-6ve0eRw4Ula2nCJtGYIJNG binary-0.8.9.0
    bytes-0.17.3-5OrkeRtEPv6EpqAaQjgnlh
    cereal-0.5.8.3-9zcITCTkqXtHoa6jbeSF22 containers-0.6.5.1
    deepseq-1.4.6.1 distributive-0.6.2.1-TinPxdMbzK5IAHiGQcUDB
    ghc-prim-0.8.0 hashable-1.4.3.0-4gqtyFKn8Wu9OwsZtyYGdt
    indexed-traversable-0.1.3-Kh350Et65iBgeXUUiKI5S
    lens-5.2.3-wl3tMgmsjtFTCF1HKVTSE
    random-1.2.1.2-LCKSS7rEcRbACR8x8dKjFH
    reflection-2.1.7-HemkYmjlWTJAh5UXuGe0A
    semigroupoids-5.3.7-2mDe4sMNPvw975Oe5bPubt
    tagged-0.8.8-404YCiJ2agdDxJGZ4AybXg template-haskell-2.18.0.0
    transformers-0.5.6.2
    transformers-compat-0.7.2-9ApmiRwA3hS7UuQpOomcS
    unordered-containers-0.2.20-8WFaf62MVyiL1uC2m0h0zY
    vector-0.13.1.0-FuSYSqJEiCU51oStZmHlCe
    void-0.7.3-KUUN4OwBuM95y1GIrgJb5t

haddock-interfaces:   /usr/share/doc/haskell-linear/html/linear.haddock
haddock-html:         /usr/share/doc/haskell-linear/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
